=========
Constants
=========


.. data:: netsgiro.NETS_ID

    Nets' data sender/recipient ID

.. autoclass:: netsgiro.ServiceCode
    :members:
    :undoc-members:

.. autoclass:: netsgiro.RecordType
    :members:
    :undoc-members:

.. autoclass:: netsgiro.AssignmentType
    :members:
    :undoc-members:

.. autoclass:: netsgiro.TransactionType
    :members:
    :undoc-members:

.. autoclass:: netsgiro.AvtaleGiroRegistrationType
    :members:
    :undoc-members:
